==> vtigercrm-5.3.0p0.tgz: modules/ConfigEditor/language/es_mx.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 * Traslated by Francisco Hernandez www.odin.mx
 ************************************************************************************/
$mod_strings = Array (
	
	'ConfigEditor' => 'Editor Configuración',
	'LBL_CONFIG_EDITOR' => 'Editor Configuración',
	'LBL_SETTINGS' => 'Configuración',
	'LBL_CONFIG_EDIT'=>'Editar la Configuración de vtiger CRM',
	'SINGLE_ConfigEditor' => 'Editor Configuración',
	'LBL_TRUE'=> 'verdadero',
	'LBL_FALSE'=> 'falso',
	'LBL_MAX_UPLOAD_SIZE_MSG'=> 'Tamaño máximo de carga es 5MB',
	'LBL_INVALID_EMAIL_MSG'=>'Correo Electrónico Inválido',
	'LBL_EMPTY_NAME_MSG'=> 'Nombre de Soporte no puede quedar vacío',
	'LBL_MAX_LISTVIEW_ENTRIES_MSG'=>'Número máximo de entradas en Vista de Lista es 100',
	'LBL_MAX_HISTORY_VIEWED_MSG'=>'Introduce un número entre 1 y 5',
	'LBL_MAX_TEXTLENGTH_LISTVIEW_MSG'=>'Longitud de texto máximo es 100',
	'LBL_MB'=>'MB',
	'LBL_MINI_CALENDAR_DISPLAY' => 'Mostrar Calendario',
	'LBL_WORLD_CLOCK_DISPLAY'=>'Mostrar Reloj Mundial',
	'LBL_CALCULATOR_DISPLAY'=>'Mostrar Calculadora',
	'LBL_USE_RTE'=>'Utilizar Editor Enriquecido',
	'LBL_HELPDESK_SUPPORT_EMAILID'=>'Email de Asistencia y Soporte',
	'LBL_HELPDESK_SUPPORT_NAME'=>'Nombre de Asistencia y Soporte',
	'LBL_MAX_UPLOAD_SIZE'=>'Tamaño máximo de carga (Máx 5MB)',
	'LBL_MAX_HISTORY_VIEWED'=>'Tamaño Histórico de Navegación',
	'LBL_DEFAULT_MODULE'=>'Módulo Inicial',
	'LBL_MAX_TEXT_LENGTH_IN_LISTVIEW'=>'Longitud de texto en vista de lista',
	'LBL_MAX_ENTRIES_PER_PAGE_IN_LISTVIEW'=>'Entradas por página en vista de lista',
	'LBL_CONFIG_FILE'=>'config.inc.php',
	'LBL_CONFIG_EDIT_CAUTION_INFO' =>'Está editando la configuración de vtiger CRM.',
	'LBL_DOUBLE_CHECK_INFO'=>'Por favor, verifique los valores introducidos antes de guardar.',
	'LBL_HELP_INFO'=>"Esto se utiliza como correo de respuesta al notificar un usuario recién creado,
					notificar de la asignación de un caso, otras notificaciones y recordatorios en general.",

);

?>

==> vtigercrm-5.4.0.tgz: modules/ConfigEditor/language/es_mx.lang.php <==
<?php
/*+**********************************************************************************
 * The contents of this file are subject to the vtiger CRM Public License Version 1.0
 * ("License"); You may not use this file except in compliance with the License
 * The Original Code is:  vtiger CRM Open Source
 * The Initial Developer of the Original Code is vtiger.
 * Portions created by vtiger are Copyright (C) vtiger.
 * All Rights Reserved.
 * 
 * ***********************************************************
*  Module       : ConfigEditor
*  Language     : ES Spanish
*  Version      : vt5.4.0
*  Created Date : 2012-02-27
*  Author       : Odin Consultores S de RL de CV
*  License      : MPL 1.1
 ************************************************************************************/
$mod_strings = Array (
	
	'ConfigEditor' => 'Editor de Configuración',
	'LBL_CONFIG_EDITOR' => 'Editor de Config.inc.php',
	'LBL_SETTINGS' => 'Parámetros',
	'LBL_CONFIG_EDIT'=>'Editar la Configuración de vtiger CRM',
	'SINGLE_ConfigEditor' => 'Editor de Configuración',
	'LBL_TRUE'=> 'verdadero',
	'LBL_FALSE'=> 'Falso',
	'LBL_MAX_UPLOAD_SIZE_MSG'=> 'Tamaño máximo de carga es 5MB',
	'LBL_INVALID_EMAIL_MSG'=>'Correo Electrónico Inválido',
	'LBL_EMPTY_NAME_MSG'=> 'Nombre de Soporte no puede quedar vacío',
	'LBL_MAX_LISTVIEW_ENTRIES_MSG'=>'Número máximo de entradas en Vista de Lista es 100',
	'LBL_MAX_HISTORY_VIEWED_MSG'=>'Introduce un número entre 1 y 5',
	'LBL_MAX_TEXTLENGTH_LISTVIEW_MSG'=>'Longitud de texto máximo es 100',
	'LBL_MB'=>'MB',
	'LBL_MINI_CALENDAR_DISPLAY' => 'Mostrar Mini Calendario',
	'LBL_WORLD_CLOCK_DISPLAY'=>'Mostrar Reloj Mundial',
	'LBL_CALCULATOR_DISPLAY'=>'Mostrar Calculadora',
	'LBL_USE_RTE'=>'Utilizar Editor Enriquecido',
	'LBL_HELPDESK_SUPPORT_EMAILID'=>'Email de Asistencia y Soporte',
	'LBL_HELPDESK_SUPPORT_NAME'=>'Nombre de Asistencia y Soporte',
	'LBL_MAX_UPLOAD_SIZE'=>'Tamaño máximo de carga (Máx 5MB)',
	'LBL_MAX_HISTORY_VIEWED'=>'Tamaño Histórico de Navegación',
	'LBL_DEFAULT_MODULE'=>'Módulo Inicial',
	'LBL_MAX_TEXT_LENGTH_IN_LISTVIEW'=>'Longitud de texto en vista de lista',
	'LBL_MAX_ENTRIES_PER_PAGE_IN_LISTVIEW'=>'Entradas por página en vista de lista',
	'LBL_CONFIG_FILE'=>'config.inc.php',
	'LBL_CONFIG_EDIT_CAUTION_INFO' =>'Estás editando la configuración de vtiger CRM.',
	'LBL_DOUBLE_CHECK_INFO'=>'Por favor, revisa dos veces antes de salvar los valores.',
	'LBL_HELP_INFO'=>"Esto se utiliza como correo de respuesta al notificar un usuario recién creado,
					notificar de la asignación de un caso, otras notificaciones y recordatorios en general.",
	'LBL_RESTRICTED_CHARACTERS'=>"Caracteres especiales como ' &#34 y ; no son permitidos",

);

?>
